# zep2md

The `zep2md` package installs a cli app that translates the text of your [Apache Zeppelin](https://zeppelin.apache.org/) file to markdown with syntax highlighting.

## Installation

You can install this via `pip`.

```
pip install zep2md
```

## Usage

```
zep2md <my_file.zpln>
```

## FAQ

> Which interpreters are supported?

At the moment only:

* `md`
* `python`
* `sh`
* `spark`
* `sql`
